==> fswiki-3.5.6.tbz: share/fswiki/plugin/attach/Ref.pm <==
############################################################
#
# <p>źեեؤΥ󥫤ɽޤ</p>
# <pre>
# {{ref ե̾}}
# </pre>
# <p>̤Υڡźդ줿ե򻲾Ȥ뤳ȤǤޤ</p>
# <pre>
# {{ref ե̾,ڡ̾}}
# </pre>
#
############################################################
package plugin::attach::Ref;
use strict;
use plugin::attach::AttachHandler;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# 饤ؿ
#===========================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $file = shift;
	my $page = shift;
	
	if($file eq ""){
		return &Util::inline_error("ե뤬ꤵƤޤ");
	}
	if($page eq ""){
		$page = $wiki->get_CGI()->param("page");
	}
	unless($wiki->can_show($page)){
		return &Util::paragraph_error("ڡλȸ¤ޤ","WIKI");
	}
	
	my $filename = $wiki->config('attach_dir')."/".&Util::url_encode($page).".".&Util::url_encode($file);
	if(-e $filename){
		my $buf = "<a href=\"".$wiki->config('script_name')."?action=ATTACH&amp;page=".
		          &Util::url_encode($page)."&amp;file=".&Util::url_encode($file)."\">".&Util::escapeHTML($file)."</a>";
		
		# ɲ
		if(-e $wiki->config('log_dir')."/".$wiki->config('attach_log_file')){
			my $count = 0;
			my $search = "DOWNLOAD ".&Util::url_encode($page)." ".&Util::url_encode($file)." ";
			open(LOG,$wiki->config('log_dir')."/".$wiki->config('attach_log_file'));
			while(<LOG>){
				if(index($_,$search)==0){
					$count++;
				}
			}
			close(LOG);
			$buf .= "($count)";
		}
		return $buf;
		
	} else {
		return &Util::inline_error("ե뤬¸ߤޤ");
	}
}

1;

==> fswiki-3.6.2_1.tbz: share/fswiki/plugin/attach/Ref.pm <==
############################################################
#
# <p>źեեؤΥ󥫤ɽޤ</p>
# <pre>
# {{ref ե̾}}
# </pre>
# <p>̤Υڡźդ줿ե򻲾Ȥ뤳ȤǤޤ</p>
# <pre>
# {{ref ե̾,ڡ̾}}
# </pre>
# <p>
#   ̾ϥ󥫤Ȥƥե̾ɽޤ
#   ̾ȤǤդʸɽ뤳ȤǤޤ
# </p>
# <pre>
# {{ref ե̾,ڡ̾,̾}}
# </pre>
#
############################################################
package plugin::attach::Ref;
use strict;
use plugin::attach::AttachHandler;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# 饤ؿ
#===========================================================
sub inline {
	my $self  = shift;
	my $wiki  = shift;
	my $file  = shift;
	my $page  = shift;
	my $alias = shift;
	
	if($file eq ""){
		return &Util::inline_error("ե뤬ꤵƤޤ");
	}
	if($page eq ""){
		$page = $wiki->get_CGI()->param("page");
	}
	unless($wiki->can_show($page)){
		return &Util::paragraph_error("ڡλȸ¤ޤ","WIKI");
	}
	if($alias eq ""){
		$alias = $file;
	}

	my $filename = $wiki->config('attach_dir')."/".&Util::url_encode($page).".".&Util::url_encode($file);
	if(-e $filename){
		my $buf = "<a href=\"".$wiki->config('script_name')."?action=ATTACH&amp;page=".
		          &Util::url_encode($page)."&amp;file=".&Util::url_encode($file)."\">".&Util::escapeHTML($alias)."</a>";
		
		# ɲ
		my $count = Util::load_config_hash(undef,$wiki->config('log_dir')."/".$wiki->config('download_count_file'));
		if(defined($count->{$page."::".$file})){
			$buf .= "(".$count->{$page."::".$file}.")";
		} else {
			$buf .= "(0)";
		}
		return $buf;
		
	} else {
		return &Util::inline_error("ե뤬¸ߤޤ");
	}
}

1;
